get_image_tweets: Get tweets containing images
`r lifecycle::badge("deprecated")
Description
This function collects tweets containing strings or
hashtags between specified date ranges that also contain (a recognized URL to) an image. Tweet-level data
is stored in a data/ path as a series of JSONs beginning "data_"; User-level data is stored as a series
of JSONs beginning "users_". If a filename is supplied, this function will save the result as a RDS file,
otherwise it will return the results as a dataframe.