powered by
This function fetches users who liked a tweet or tweets.
get_liking_users(x, bearer_token = get_bearer(), verbose = TRUE)
string containing one tweet id or a vector of tweet ids
string, bearer token
If FALSE, query progress messages are suppressed
FALSE
a data frame
# NOT RUN { tweet <- "1387744422729748486" get_liking_users(tweet, bearer_token = get_bearer()) # }
Run the code above in your browser using DataLab