character vector containing screen names to be queried
bearer_token
string, bearer token
all
logical, default FALSE to get a character vector of user IDs. Set it to TRUE to get a data frame, see below
keep_na
logical, default TRUE to keep usernames that cannot be queried. Set it to TRUE to exclude those usernames. Only useful when all is FALSE
Value
a string vector with the id of each of the users unless all = TRUE. If all = TRUE, a data.frame with ids, names (showed on the screen) and usernames is returned.